@@ -49,17 +49,22 @@ class DDBSCAN:
         self.last_index = 0 
         self.tree = None
         
-    def add_point(self, point, count, desc):
+    def add_point(self, point, count, desc, compute_increment=False):
         """ Add a new point (passed as a n-dimensional list [x, y, z, ...]) to model updating it's neighbours.
             It's description will be set to desc. 
         """
         self.last_index = self.points.index(point) if point in self.points else -1
         if self.last_index != -1: # If point already seem
-            self.points_data[self.last_index].count = self.points_data[self.last_index].count + count
+            # If it's to compute increment, it's just count - previous_count
+            if compute_increment:
+                count = count - self.points_data[self.last_index].count
+                if count < 0:
+                    raise ValueError('Error computing increment: negative value found.')
+
+            self.points_data[self.last_index].count += count
             self.points_data[self.last_index].desc = desc
             for neighbour_index in self.points_data[self.last_index].neighbourhood:
-                self.points_data[neighbour_index].size_neighbourhood = \
-                    self.points_data[neighbour_index].size_neighbourhood + count
+                self.points_data[neighbour_index].size_neighbourhood += count
         else:
             # Add point to list and update last_index
             self.last_index = len(self.points)
@@ -77,10 +82,9 @@ class DDBSCAN:
             # Calculate size of neighbourhood and add this to their neighbourhood
             for neighbour_index in self.points_data[self.last_index].neighbourhood:
                 if neighbour_index != self.last_index: # Update others in neighbourhood
-                    self.points_data[self.last_index].size_neighbourhood = \
-                        self.points_data[self.last_index].size_neighbourhood + self.points_data[neighbour_index].count
+                    self.points_data[self.last_index].size_neighbourhood += self.points_data[neighbour_index].count
                     self.points_data[neighbour_index].neighbourhood.append(self.last_index)
-                    self.points_data[neighbour_index].size_neighbourhood = self.points_data[neighbour_index].size_neighbourhood + count
+                    self.points_data[neighbour_index].size_neighbourhood += count
     
     def set_params(self, eps, min_pts):
         """ Set params and update structures. """
@@ -93,11 +97,10 @@ class DDBSCAN:
             self.points_data[i].neighbourhood = self.tree.query_ball_point(self.points[i], self.eps)
             self.points_data[i].size_neighbourhood = 0
         
-        # Update size -f neighbourhood
+        # Update neighbourhood size
         for i in xrange(len(self.points)):
             for neighbour_index in self.points_data[i].neighbourhood:
-                self.points_data[i].size_neighbourhood = \
-                        self.points_data[i].size_neighbourhood + self.points_data[neighbour_index].count
+                self.points_data[i].size_neighbourhood += self.points_data[neighbour_index].count
 
     def compute(self):
         """ Compute clusters. """
